Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(345)

Unified Diff: components/autofill/content/browser/autocheckout_manager.h

Issue 18179015: Send IPC from renderer to browser on each Autocheckout page completion (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: put local variable old_metadata back. Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/content/browser/autocheckout_manager.h
diff --git a/components/autofill/content/browser/autocheckout_manager.h b/components/autofill/content/browser/autocheckout_manager.h
index e28304789084cb331506dad5f3208ad43492d229..602c00ca3adf5578b512226b36bd79c23196640d 100644
--- a/components/autofill/content/browser/autocheckout_manager.h
+++ b/components/autofill/content/browser/autocheckout_manager.h
@@ -49,9 +49,9 @@ class AutocheckoutManager {
// gathered from the requestAutocomplete dialog.
void FillForms();
- // Called when clicking a proceed element in an Autocheckout flow fails.
- // |status| is the reason for the failure.
- void OnClickFailed(AutocheckoutStatus status);
+ // Called to signal a page is completed in renderer in the Autocheckout flow.
+ // |status| is the reason for the failure, it is |SUCCESS| if no errors.
Ilya Sherman 2013/07/16 22:56:26 Optional nit: Suggested minor wording tweaks: "Ca
benquan 2013/07/17 00:28:57 Done.
+ void OnAutocheckoutPageCompleted(AutocheckoutStatus status);
// Sets |page_meta_data_| with the meta data for the current page.
void OnLoadedPageMetaData(
@@ -128,6 +128,9 @@ class AutocheckoutManager {
// towards |page_number|.
void RecordTimeTaken(int page_number);
+ // Terminate the Autocheckout flow and send Autocheckout status.
Ilya Sherman 2013/07/16 22:56:26 nit: Send the status where?
benquan 2013/07/17 00:28:57 Done.
+ void EndAutocheckout(AutocheckoutStatus status);
+
AutofillManager* autofill_manager_; // WEAK; owns us
// Credit card verification code.

Powered by Google App Engine
This is Rietveld 408576698